@@ -124,6 +124,11 @@ public:
   void setTime(const double& t);
   double getTime();
 
+  /// Set modification status of independent variables
+  //  (exploited by linear equation systems in Jacobians)
+  void setFreeVariablesLock(bool freeVariablesLock);
+  bool getFreeVariablesLock();
+
   IGlobalSettings* getGlobalSettings();
 
   shared_ptr<ISimObjects> getSimObjects() const;
@@ -141,14 +146,18 @@ public:
   virtual bool& getBoolStartValue(bool& var);
   virtual int& getIntStartValue(int& var);
   virtual string& getStringStartValue(string& var);
-  virtual void setRealStartValue(double& var,double val);
-  virtual void setRealStartValue(double& var,double val,bool overwriteOldValue);
-  virtual void setBoolStartValue(bool& var,bool val);
-  virtual void setBoolStartValue(bool& var,bool val,bool overwriteOldValue);
-  virtual void setIntStartValue(int& var,int val);
-  virtual void setIntStartValue(int& var,int val,bool overwriteOldValue);
-  virtual void setStringStartValue(string& var,string val);
-  virtual void setStringStartValue(string& var,string val,bool overwriteOldValue);
+  virtual void setRealStartValue(double& var, double val, bool overwriteOldValue = false);
+  virtual void setRealStartValue(BaseArray<double>& avar, double val, bool overwriteOldValue = false);
+  virtual void setRealStartValue(BaseArray<double>& avar, const BaseArray<double>& aval, bool overwriteOldValue = false);
+  virtual void setBoolStartValue(bool& var, bool val, bool overwriteOldValue = false);
+  virtual void setBoolStartValue(BaseArray<bool>& avar, bool val, bool overwriteOldValue = false);
+  virtual void setBoolStartValue(BaseArray<bool>& avar, const BaseArray<bool>& aval, bool overwriteOldValue = false);
+  virtual void setIntStartValue(int& var,int val, bool overwriteOldValue = false);
+  virtual void setIntStartValue(BaseArray<int>& avar, int val, bool overwriteOldValue = false);
+  virtual void setIntStartValue(BaseArray<int>& avar, const BaseArray<int>& aval, bool overwriteOldValue = false);
+  virtual void setStringStartValue(string& var, string val, bool overwriteOldValue = false);
+  virtual void setStringStartValue(BaseArray<string>& avar, string val, bool overwriteOldValue = true);
+  virtual void setStringStartValue(BaseArray<string>& avar, const BaseArray<string>& aval, bool overwriteOldValue = true);
 protected:
     void Assert(bool cond, const string& msg);
     void Terminate(string msg);
@@ -220,5 +229,24 @@ protected:
 
   bool _sparse;
   bool _useAnalyticalJacobian;
+
+  bool _freeVariablesLock; ///< modification status of independent variables
+};
+
+/// Mark free variables unchanged.
+/// Automatically release lock upon destruction, covering exceptions as well.
+class SystemLockFreeVariables {
+ public:
+  SystemLockFreeVariables(SystemDefaultImplementation *system, bool lock = true) {
+    system->setFreeVariablesLock(lock);
+    _system = system;
+  }
+
+  ~SystemLockFreeVariables() {
+    _system->setFreeVariablesLock(false);
+  }
+
+ private:
+  SystemDefaultImplementation *_system;
 };
 /** @} */ // end of coreSystem
