@@ -509,7 +509,9 @@ public:
   QToolButton* getDiagramViewToolButton() {return mpDiagramViewToolButton;}
   QToolButton* getTextViewToolButton() {return mpTextViewToolButton;}
   QToolButton* getDocumentationViewToolButton() {return mpDocumentationViewToolButton;}
+  void setDiagramGraphicsView(GraphicsView *pDiagramGraphicsView) {mpDiagramGraphicsView = pDiagramGraphicsView;}
   GraphicsView* getDiagramGraphicsView() {return mpDiagramGraphicsView;}
+  void setIconGraphicsView(GraphicsView *pIconGraphicsView) {mpIconGraphicsView = pIconGraphicsView;}
   GraphicsView* getIconGraphicsView() {return mpIconGraphicsView;}
   UndoStack* getUndoStack() {return mpUndoStack;}
   BaseEditor* getEditor() {return mpEditor;}
@@ -628,6 +630,7 @@ private:
   void associateBusWithConnector(QString busName, QString connectorName, GraphicsView *pGraphicsView);
   void dissociateBusWithConnector(QString busName, QString connectorName, GraphicsView *pGraphicsView);
   void associateBusWithConnectors(Element *pBusComponent, GraphicsView *pGraphicsView);
+  static void removeInheritedClasses(LibraryTreeItem *pLibraryTreeItem);
 private slots:
   void showIconView(bool checked);
   void showDiagramView(bool checked);
