@@ -110,11 +110,11 @@ namespace IAEX
         if( cstyle.name() != "null" )
           text->setStyle( cstyle );
         else
-          throw runtime_error("No Input style defened, the inputcell may not work correctly, please define a Input style in stylesheet.xml");
+          throw runtime_error("No Input style defined, the inputcell may not work correctly, please define an Input style in stylesheet.xml");
       }
       catch( exception e )
       {
-        QMessageBox::warning( 0, "Warning", e.what(), "OK" );
+        QMessageBox::warning( 0, QObject::tr("Warning"), e.what(), "OK" );
       }
 
       try
@@ -196,12 +196,12 @@ namespace IAEX
 
           text->setStyle( cstyle );
         else
-          throw runtime_error("No Input style defened, the inputcell may not work correctly, please define a Input style in stylesheet.xml");
+          throw runtime_error("No Input style defined, the inputcell may not work correctly, please define an Input style in stylesheet.xml");
       }
       catch( exception e )
       {
 
-        QMessageBox::warning( 0, "Warrning", e.what(), "OK" );
+        QMessageBox::warning( 0, QObject::tr("Warning"), e.what(), "OK" );
       }
 
       QObject::connect(text, SIGNAL(cellselected(Cell *,Qt::KeyboardModifiers)),
@@ -236,14 +236,6 @@ namespace IAEX
       QObject::connect(text->output_, SIGNAL(undoAvailable(bool)), doc_, SIGNAL(undoAvailable(bool)));
       QObject::connect(text->output_, SIGNAL(redoAvailable(bool)), doc_, SIGNAL(redoAvailable(bool)));
 
-      //      if(CellDocument* d = dynamic_cast<CellDocument*>(doc_))
-      QObject::connect(doc_, SIGNAL(setAutoIndent(bool)), text->input_, SLOT(setAutoIndent(bool)));
-      QObject::connect(doc_, SIGNAL(setAutoIndent(bool)), text->output_, SLOT(setAutoIndent(bool)));
-
-      //QObject::connect(doc_, SIGNAL(evaluate()), text->input_, SIGNAL(eval()));
-      text->input_->setAutoIndent(dynamic_cast<CellDocument*>(doc_)->autoIndent);
-      text->output_->setAutoIndent(dynamic_cast<CellDocument*>(doc_)->autoIndent);
-
       return text;
     }
 
@@ -260,11 +252,11 @@ namespace IAEX
         if( cstyle.name() != "null" )
           text->setStyle( cstyle );
         else
-          throw runtime_error("No Input style defened, the inputcell may not work correctly, please define a Input style in stylesheet.xml");
+          throw runtime_error("No Input style defined, the inputcell may not work correctly, please define an Input style in stylesheet.xml");
       }
       catch( exception e )
       {
-        QMessageBox::warning( 0, "Warrning", e.what(), "OK" );
+        QMessageBox::warning( 0, QObject::tr("Warning"), e.what(), "OK" );
       }
 
       try
