@@ -253,12 +253,14 @@ namespace IAEX
       throw e;
     }
 
+/* Do not throw an error if empty notebook is opened
     // check if root cell is empty
     if( !rootcell->hasChilds() )
     {
       string msg = "File " + filename_.toStdString() + " is empty";
       throw runtime_error( msg.c_str() );
     }
+*/
 
     return rootcell;
   }
@@ -627,7 +629,7 @@ namespace IAEX
             QDomElement curveElement = n.toElement();
             if (curveElement.tagName() == XML_GRAPHCELL_CURVE)
             {
-              PlotCurve *pPlotCurve = new PlotCurve("", curveElement.attribute(XML_GRAPHCELL_TITLE), "", "", gCell->mpPlotWindow->getPlot());
+              PlotCurve *pPlotCurve = new PlotCurve("", "", curveElement.attribute(XML_GRAPHCELL_TITLE), "", curveElement.attribute(XML_GRAPHCELL_TITLE), "", "", gCell->mpPlotWindow->getPlot());
               // read the curve data
               if (curveElement.hasAttribute(XML_GRAPHCELL_XDATA) && curveElement.hasAttribute(XML_GRAPHCELL_YDATA))
               {
