@@ -38,6 +38,7 @@
 #include "System.h"
 #include "SystemTLM.h"
 #include "SystemWC.h"
+
 #include <fmilib.h>
 #include <JM/jm_portability.h>
 #include <OMSFileSystem.h>
@@ -86,7 +87,7 @@ oms::Component* oms::ComponentFMUCS::NewComponent(const oms::ComRef& cref, oms::
   component->callbacks.context = 0;
 
   // Copy the resource to the temp directory of the model? We don't want have
-  // do copy resources if importing an SSP or snapshot.
+  // to copy resources if importing an SSP file or snapshot.
   if (parentSystem->copyResources())
     oms_copy_file(filesystem::path(fmuPath), absFMUPath);
 
@@ -208,6 +209,8 @@ oms::Component* oms::ComponentFMUCS::NewComponent(const oms::ComRef& cref, oms::
     }
     else if (v.isParameter())
       component->parameters.push_back(v);
+    else if (v.isCalculatedParameter())
+      component->calculatedParameters.push_back(v);
 
     if (v.isInitialUnknown())
       component->initialUnknownsGraph.addNode(Connector(v.getCausality(), v.getType(), v.getCref()));
@@ -229,22 +232,37 @@ oms::Component* oms::ComponentFMUCS::NewComponent(const oms::ComRef& cref, oms::
     component->connectors.push_back(new Connector(oms_causality_output, v.getType(), v.getCref(), i++/(double)size));
   for (const auto& v : component->parameters)
     component->connectors.push_back(new Connector(oms_causality_parameter, v.getType(), v.getCref()));
+  for (const auto& v : component->calculatedParameters)
+    component->connectors.push_back(new Connector(oms_causality_calculatedParameter, v.getType(), v.getCref()));
   component->connectors.push_back(NULL);
   component->element.setConnectors(&component->connectors[0]);
 
-  component->initializeDependencyGraph_initialUnknowns();
-  component->initializeDependencyGraph_outputs();
+  if (oms_status_ok != component->initializeDependencyGraph_initialUnknowns())
+  {
+    logError(std::string(cref) + ": Couldn't initialize dependency graph for initial unknowns.");
+    delete component;
+    return NULL;
+  }
+  if (oms_status_ok != component->initializeDependencyGraph_outputs())
+  {
+    logError(std::string(cref) + ": Couldn't initialize dependency graph for simulation unknowns.");
+    delete component;
+    return NULL;
+  }
+
+  // parse modelDescription.xml to get start values before instantiating fmu's
+  component->values.parseModelDescription((tempDir / "modelDescription.xml").string().c_str());
 
   return component;
 }
 
-oms::Component* oms::ComponentFMUCS::NewComponent(const pugi::xml_node& node, oms::System* parentSystem)
+oms::Component* oms::ComponentFMUCS::NewComponent(const pugi::xml_node& node, oms::System* parentSystem, const std::string& sspVersion)
 {
   ComRef cref = ComRef(node.attribute("name").as_string());
   std::string type = node.attribute("type").as_string();
   std::string source = node.attribute("source").as_string();
 
-  if (type != "application/x-fmu-sharedlibrary")
+  if (type != "application/x-fmu-sharedlibrary" && !type.empty())
   {
     logError("Unexpected component type: " + type);
     return NULL;
@@ -261,20 +279,26 @@ oms::Component* oms::ComponentFMUCS::NewComponent(const pugi::xml_node& node, om
   for(pugi::xml_node_iterator it = node.begin(); it != node.end(); ++it)
   {
     std::string name = it->name();
-    if(name == oms::ssd::ssd_connectors)
+    if(name == oms::ssp::Draft20180219::ssd::connectors)
     {
       // import connectors
       for(pugi::xml_node_iterator itConnectors = (*it).begin(); itConnectors != (*it).end(); ++itConnectors)
       {
-        component->connectors.push_back(oms::Connector::NewConnector(*itConnectors));
+        component->connectors.push_back(oms::Connector::NewConnector(*itConnectors, sspVersion));
       }
     }
-    else if(name == oms::ssd::ssd_element_geometry)
+    else if(name == oms::ssp::Draft20180219::ssd::element_geometry)
     {
       oms::ssd::ElementGeometry geometry;
       geometry.importFromSSD(*it);
       component->setGeometry(geometry);
     }
+    else if(name == oms::ssp::Version1_0::ssd::parameter_bindings)
+    {
+      // set parameter bindings associated with the component
+      std::string tempdir = parentSystem->getModel()->getTempDirectory();
+      component->values.importFromSSD(*it, sspVersion, tempdir);
+    }
     else
     {
       logError_WrongSchema(name);
@@ -289,14 +313,14 @@ oms::Component* oms::ComponentFMUCS::NewComponent(const pugi::xml_node& node, om
   return component;
 }
 
-oms_status_enu_t oms::ComponentFMUCS::exportToSSD(pugi::xml_node& node) const
+oms_status_enu_t oms::ComponentFMUCS::exportToSSD(pugi::xml_node& node, pugi::xml_node& ssvNode) const
 {
 #if !defined(NO_TLM)
   if (tlmbusconnectors[0])
   {
-    pugi::xml_node annotations_node = node.append_child(oms::ssd::ssd_annotations);
-    pugi::xml_node annotation_node = annotations_node.append_child(oms::ssd::ssd_annotation);
-    annotation_node.append_attribute("type") = oms::annotation_type;
+    pugi::xml_node annotations_node = node.append_child(oms::ssp::Draft20180219::ssd::annotations);
+    pugi::xml_node annotation_node = annotations_node.append_child(oms::ssp::Version1_0::ssc::annotation);
+    annotation_node.append_attribute("type") = oms::ssp::Draft20180219::annotation_type;
     for (const auto& tlmbusconnector : tlmbusconnectors)
       if (tlmbusconnector)
         tlmbusconnector->exportToSSD(annotation_node);
@@ -306,7 +330,7 @@ oms_status_enu_t oms::ComponentFMUCS::exportToSSD(pugi::xml_node& node) const
   node.append_attribute("name") = this->getCref().c_str();
   node.append_attribute("type") = "application/x-fmu-sharedlibrary";
   node.append_attribute("source") = getPath().c_str();
-  pugi::xml_node node_connectors = node.append_child(oms::ssd::ssd_connectors);
+  pugi::xml_node node_connectors = node.append_child(oms::ssp::Draft20180219::ssd::connectors);
 
   if (element.getGeometry())
     element.getGeometry()->exportToSSD(node);
@@ -315,6 +339,23 @@ oms_status_enu_t oms::ComponentFMUCS::exportToSSD(pugi::xml_node& node) const
     if (connector)
       if (oms_status_ok != connector->exportToSSD(node_connectors))
         return oms_status_error;
+
+  // export ParameterBindings at component level
+  if (Flags::ExportParametersInline()) // export as inline
+  {
+    values.exportToSSD(node);
+  }
+  else
+  {
+    values.exportToSSV(ssvNode); // export to ssv file
+  }
+
+  return oms_status_ok;
+}
+
+oms_status_enu_t oms::ComponentFMUCS::exportToSSVTemplate(pugi::xml_node& ssvNode)
+{
+  values.exportToSSVTemplate(ssvNode, getCref());
   return oms_status_ok;
 }
 
@@ -326,6 +367,18 @@ oms_status_enu_t oms::ComponentFMUCS::initializeDependencyGraph_initialUnknowns(
     return oms_status_error;
   }
 
+  if (Flags::IgnoreInitialUnknowns())
+  {
+    int N=initialUnknownsGraph.getNodes().size();
+    for (int i = 0; i < N; i++)
+    {
+      logDebug(std::string(getCref()) + ": " + getPath() + " initial unknown " + std::string(initialUnknownsGraph.getNodes()[i]) + " depends on all");
+      for (int j = 0; j < inputs.size(); j++)
+        initialUnknownsGraph.addEdge(inputs[j].makeConnector(), initialUnknownsGraph.getNodes()[i]);
+    }
+    return oms_status_ok;
+  }
+
   size_t *startIndex=NULL, *dependency=NULL;
   char* factorKind;
 
@@ -354,6 +407,12 @@ oms_status_enu_t oms::ComponentFMUCS::initializeDependencyGraph_initialUnknowns(
     {
       for (size_t j = startIndex[i]; j < startIndex[i + 1]; j++)
       {
+        if (dependency[j] < 1 || dependency[j] > allVariables.size())
+        {
+          logWarning("Initial unknown " + std::string(initialUnknownsGraph.getNodes()[i]) + " has bad dependency on variable with index " + std::to_string(dependency[j]) + " which couldn't be resolved");
+          logInfo("Use flag --ignoreInitialUnknowns=true to ignore all dependencies, but this can cause inflated loop size.");
+          return logError(std::string(getCref()) + ": erroneous dependencies detected in modelDescription.xml");
+        }
         logDebug(std::string(getCref()) + ": " + getPath() + " initial unknown " + std::string(initialUnknownsGraph.getNodes()[i]) + " depends on " + std::string(allVariables[dependency[j] - 1]));
         initialUnknownsGraph.addEdge(allVariables[dependency[j] - 1].makeConnector(), initialUnknownsGraph.getNodes()[i]);
       }
@@ -398,6 +457,11 @@ oms_status_enu_t oms::ComponentFMUCS::initializeDependencyGraph_outputs()
     {
       for (size_t j = startIndex[i]; j < startIndex[i + 1]; j++)
       {
+        if (dependency[j] < 1 || dependency[j] > allVariables.size())
+        {
+          logWarning("Output " + std::string(outputs[i]) + " has bad dependency on variable with index " + std::to_string(dependency[j]) + " which couldn't be resolved");
+          return logError(std::string(getCref()) + ": erroneous dependencies detected in modelDescription.xml");
+        }
         logDebug(std::string(getCref()) + ": " + getPath() + " output " + std::string(outputs[i]) + " depends on " + std::string(allVariables[dependency[j] - 1]));
         outputsGraph.addEdge(allVariables[dependency[j] - 1].makeConnector(), outputs[i].makeConnector());
       }
@@ -415,31 +479,31 @@ oms_status_enu_t oms::ComponentFMUCS::instantiate()
   // load the FMU shared library
   jmstatus = fmi2_import_create_dllfmu(fmu, fmi2_fmu_kind_cs, &callbackFunctions);
   if (jm_status_error == jmstatus)
-    return logError("Could not create the DLL loading mechanism (C-API). Error: " + std::string(fmi2_import_get_last_error(fmu)));
+    return logError("Could not load \"" + getPath() + "\" which is associated with \"" + std::string(getFullCref()) + "\"; it may be corrupted or may not support your platform");
 
   jmstatus = fmi2_import_instantiate(fmu, getCref().c_str(), fmi2_cosimulation, NULL, fmi2_false);
   if (jm_status_error == jmstatus)
     return logError_FMUCall("fmi2_import_instantiate", this);
 
   // set start values
-  for (const auto& v : booleanStartValues)
+  for (const auto& v : values.booleanStartValues)
   {
-    if (oms_status_ok != setBoolean(v.first, v.second))
+    oms::ComRef cref = getValidCref(v.first);
+    if (oms_status_ok != setBoolean(cref, v.second))
       return logError("Failed to set start value for " + std::string(v.first));
   }
-  booleanStartValues.clear();
-  for (const auto& v : integerStartValues)
+  for (const auto& v : values.integerStartValues)
   {
-    if (oms_status_ok != setInteger(v.first, v.second))
+    oms::ComRef cref = getValidCref(v.first);
+    if (oms_status_ok != setInteger(cref, v.second))
       return logError("Failed to set start value for " + std::string(v.first));
   }
-  integerStartValues.clear();
-  for (const auto& v : realStartValues)
+  for (const auto& v : values.realStartValues)
   {
-    if (oms_status_ok != setReal(v.first, v.second))
+    oms::ComRef cref = getValidCref(v.first);
+    if (oms_status_ok != setReal(cref, v.second))
       return logError("Failed to set start value for " + std::string(v.first));
   }
-  realStartValues.clear();
 
   // enterInitialization
   time = getModel()->getStartTime();
@@ -454,6 +518,23 @@ oms_status_enu_t oms::ComponentFMUCS::instantiate()
   return oms_status_ok;
 }
 
+
+/*
+ * function which returns validCrefs
+ * (e.g) add.P => P
+ * (e.g) chassis.C.mChassis => C.mChassis
+ * inline parameters should be returned as default value (e.g.) P => P or C.mChassis => C.mChassis
+ */
+oms::ComRef oms::ComponentFMUCS::getValidCref(ComRef cref)
+{
+  oms::ComRef tail(cref);
+  oms::ComRef head = tail.pop_front();
+
+  if (tail.isEmpty() || head != getCref()) // check for inline parameter crefs, (e.g.) P => P or C.mChassis => C.mChassis
+    tail = cref;
+  return tail;
+}
+
 oms_status_enu_t oms::ComponentFMUCS::initialize()
 {
   clock.reset();
@@ -558,6 +639,29 @@ oms_status_enu_t oms::ComponentFMUCS::getBoolean(const fmi2_value_reference_t& v
 oms_status_enu_t oms::ComponentFMUCS::getBoolean(const ComRef& cref, bool& value)
 {
   CallClock callClock(clock);
+
+  if (oms_modelState_virgin == getModel()->getModelState())
+  {
+    // check for start values exist, priority over modeldescription.xml start values
+    auto booleanValue = values.booleanStartValues.find(cref);
+    if (booleanValue != values.booleanStartValues.end())
+    {
+      value = booleanValue->second;
+      return oms_status_ok;
+    }
+    else
+    {
+      // search in modelDescription.xml
+      auto booleanValue = values.modelDescriptionBooleanStartValues.find(cref);
+      if (booleanValue != values.modelDescriptionBooleanStartValues.end())
+      {
+        value = booleanValue->second;
+        return oms_status_ok;
+      }
+    }
+    return logError("no start value provided or available for signal: " + std::string(getFullCref() + cref));
+  }
+
   int j=-1;
   for (size_t i = 0; i < allVariables.size(); i++)
   {
@@ -588,6 +692,29 @@ oms_status_enu_t oms::ComponentFMUCS::getInteger(const fmi2_value_reference_t& v
 oms_status_enu_t oms::ComponentFMUCS::getInteger(const ComRef& cref, int& value)
 {
   CallClock callClock(clock);
+
+  if (oms_modelState_virgin == getModel()->getModelState())
+  {
+    // check for start values exist, priority over modeldescription.xml start values
+    auto integerValue = values.integerStartValues.find(cref);
+    if (integerValue != values.integerStartValues.end())
+    {
+      value = integerValue->second;
+      return oms_status_ok;
+    }
+    else
+    {
+      // search in modelDescription.xml
+      auto integerValue = values.modelDescriptionIntegerStartValues.find(cref);
+      if (integerValue != values.modelDescriptionIntegerStartValues.end())
+      {
+        value = integerValue->second;
+        return oms_status_ok;
+      }
+    }
+    return logError("no start value set or available for signal: " + std::string(getFullCref() + cref));
+  }
+
   int j=-1;
   for (size_t i = 0; i < allVariables.size(); i++)
   {
@@ -657,6 +784,29 @@ oms_status_enu_t oms::ComponentFMUCS::getReal(const fmi2_value_reference_t& vr,
 oms_status_enu_t oms::ComponentFMUCS::getReal(const ComRef& cref, double& value)
 {
   CallClock callClock(clock);
+
+  if (oms_modelState_virgin == getModel()->getModelState())
+  {
+    // check for start values exist, priority over modeldescription.xml start values
+    auto realValue = values.realStartValues.find(cref);
+    if (realValue != values.realStartValues.end())
+    {
+      value = realValue->second;
+      return oms_status_ok;
+    }
+    else
+    {
+      // search in modelDescription.xml
+      auto realValue = values.modelDescriptionRealStartValues.find(cref);
+      if (realValue != values.modelDescriptionRealStartValues.end())
+      {
+        value = realValue->second;
+        return oms_status_ok;
+      }
+    }
+    return logError("no start value set or available for signal: " + std::string(getFullCref() + cref));
+  }
+
   int j=-1;
   for (size_t i = 0; i < allVariables.size(); i++)
   {
@@ -741,7 +891,17 @@ oms_status_enu_t oms::ComponentFMUCS::setBoolean(const ComRef& cref, bool value)
     return logError_UnknownSignal(getFullCref() + cref);
 
   if (oms_modelState_virgin == getModel()->getModelState())
-    booleanStartValues[allVariables[j].getCref()] = value;
+  {
+    if (Flags::ExportParametersInline())
+    {
+      values.setBoolean(allVariables[j].getCref(), value);
+    }
+    else
+    {
+      // append startValues with prefix (e.g) addP.K1
+      values.setBoolean(getCref()+allVariables[j].getCref(), value);
+    }
+  }
   else
   {
     fmi2_value_reference_t vr = allVariables[j].getValueReference();
@@ -770,7 +930,17 @@ oms_status_enu_t oms::ComponentFMUCS::setInteger(const ComRef& cref, int value)
     return logError_UnknownSignal(getFullCref() + cref);
 
   if (oms_modelState_virgin == getModel()->getModelState())
-    integerStartValues[allVariables[j].getCref()] = value;
+  {
+    if (Flags::ExportParametersInline())
+    {
+      values.setInteger(allVariables[j].getCref(), value);
+    }
+    else
+    {
+      // append startValues with prefix (e.g) addP.K1
+      values.setInteger(getCref()+allVariables[j].getCref(), value);
+    }
+  }
   else
   {
     fmi2_value_reference_t vr = allVariables[j].getValueReference();
@@ -802,7 +972,17 @@ oms_status_enu_t oms::ComponentFMUCS::setReal(const ComRef& cref, double value)
       return logWarning("It is not allowed to provide a start value if initial=\"calculated\" or causality=\"independent\".");
 
   if (oms_modelState_virgin == getModel()->getModelState())
-    realStartValues[allVariables[j].getCref()] = value;
+  {
+    if (Flags::ExportParametersInline())
+    {
+      values.setReal(allVariables[j].getCref(), value);
+    }
+    else
+    {
+      // append startValues with prefix (e.g) addP.K1
+      values.setReal(getCref()+allVariables[j].getCref(), value);
+    }
+  }
   else
   {
     fmi2_value_reference_t vr = allVariables[j].getValueReference();
@@ -813,6 +993,11 @@ oms_status_enu_t oms::ComponentFMUCS::setReal(const ComRef& cref, double value)
   return oms_status_ok;
 }
 
+oms_status_enu_t oms::ComponentFMUCS::deleteStartValue(const ComRef& cref)
+{
+  return values.deleteStartValue(cref);
+}
+
 oms_status_enu_t oms::ComponentFMUCS::registerSignalsForResultFile(ResultWriter& resultFile)
 {
   resultFileMapping.clear();
