@@ -5,10 +5,6 @@
 
 #include <OMSimulator.h>
 
-#ifdef WITH_OMSYSIDENT
-#include <OMSysIdent.h>
-#endif /* WITH_OMSYSIDENT */
-
 #define REGISTER_LUA_CALL(name) lua_register(L, #name, OMSimulatorLua_##name)
 #define REGISTER_LUA_ENUM(name) lua_pushnumber(L, name); lua_setglobal(L, #name)
 
@@ -262,6 +258,42 @@ static int OMSimulatorLua_oms_list(lua_State *L)
   return 2;
 }
 
+//oms_status_enu_t oms_exportSnapshot(const char* cref, char** contents);
+static int OMSimulatorLua_oms_exportSnapshot(lua_State *L)
+{
+  if (lua_gettop(L) != 1)
+    return luaL_error(L, "expecting exactly 1 argument");
+  luaL_checktype(L, 1, LUA_TSTRING);
+
+  const char* cref = lua_tostring(L, 1);
+  char* contents = NULL;
+  oms_status_enu_t status = oms_exportSnapshot(cref, &contents);
+
+  lua_pushstring(L, contents ? contents : "");
+  lua_pushinteger(L, status);
+
+  if (contents)
+    oms_freeMemory(contents);
+
+  return 2;
+}
+
+//oms_status_enu_t oms_exportSSVTemplate(const char* cref, const char* filename);
+static int OMSimulatorLua_oms_exportSSVTemplate(lua_State *L)
+{
+  if (lua_gettop(L) != 2)
+    return luaL_error(L, "expecting exactly 2 arguments");
+  luaL_checktype(L, 1, LUA_TSTRING);
+  luaL_checktype(L, 2, LUA_TSTRING);
+
+  const char* cref = lua_tostring(L, 1);
+  const char* filename = lua_tostring(L, 2);
+  oms_status_enu_t status = oms_exportSSVTemplate(cref, filename);
+
+  lua_pushinteger(L, status);
+  return 1;
+}
+
 //oms_status_enu_t oms_listUnconnectedConnectors(const char* cref, char** contents);
 static int OMSimulatorLua_oms_listUnconnectedConnectors(lua_State *L)
 {
@@ -282,21 +314,55 @@ static int OMSimulatorLua_oms_listUnconnectedConnectors(lua_State *L)
   return 2;
 }
 
-//oms_status_enu_t oms_exportDependencyGraphs(const char* cref, const char* initialization, const char* simulation);
+//oms_status_enu_t oms_loadSnapshot(const char* cref, const char* snapshot);
+static int OMSimulatorLua_oms_loadSnapshot(lua_State *L)
+{
+  if (lua_gettop(L) != 2)
+    return luaL_error(L, "expecting exactly 2 arguments\n<integer> = oms_loadSnapshot(<string>, <string>)");
+  luaL_checktype(L, 1, LUA_TSTRING);
+  luaL_checktype(L, 2, LUA_TSTRING);
+
+  const char* cref = lua_tostring(L, 1);
+  const char* snapshot = lua_tostring(L, 2);
+  oms_status_enu_t status = oms_loadSnapshot(cref, snapshot);
+
+  lua_pushinteger(L, status);
+  return 1;
+}
+
+//oms_status_enu_t oms_importSnapshot(const char* cref, const char* snapshot);
+static int OMSimulatorLua_oms_importSnapshot(lua_State *L)
+{
+  if (lua_gettop(L) != 2)
+    return luaL_error(L, "expecting exactly 2 arguments\n<integer> = oms_loadSnapshot(<string>, <string>)");
+  luaL_checktype(L, 1, LUA_TSTRING);
+  luaL_checktype(L, 2, LUA_TSTRING);
+
+  const char* cref = lua_tostring(L, 1);
+  const char* snapshot = lua_tostring(L, 2);
+  oms_status_enu_t status = oms_importSnapshot(cref, snapshot);
+
+  lua_pushinteger(L, status);
+  return 1;
+}
+
+//oms_status_enu_t oms_exportDependencyGraphs(const char* cref, const char* initialization, const char* event, const char* simulation);
 static int OMSimulatorLua_oms_exportDependencyGraphs(lua_State *L)
 {
-  if (lua_gettop(L) != 3)
-    return luaL_error(L, "expecting exactly 3 arguments");
+  if (lua_gettop(L) != 4)
+    return luaL_error(L, "expecting exactly 4 arguments");
 
   luaL_checktype(L, 1, LUA_TSTRING);
   luaL_checktype(L, 2, LUA_TSTRING);
   luaL_checktype(L, 3, LUA_TSTRING);
+  luaL_checktype(L, 4, LUA_TSTRING);
 
   const char* cref = lua_tostring(L, 1);
   const char* initialization = lua_tostring(L, 2);
-  const char* simulation = lua_tostring(L, 3);
+  const char* event = lua_tostring(L, 3);
+  const char* simulation = lua_tostring(L, 4);
 
-  oms_status_enu_t status = oms_exportDependencyGraphs(cref, initialization, simulation);
+  oms_status_enu_t status = oms_exportDependencyGraphs(cref, initialization, event, simulation);
   lua_pushinteger(L, status);
   return 1;
 }
@@ -342,23 +408,6 @@ static int OMSimulatorLua_oms_compareSimulationResults(lua_State *L)
   return 1;
 }
 
-//oms_status_enu_t oms_importString(const char* contents, char** cref);
-static int OMSimulatorLua_oms_importString(lua_State *L)
-{
-  if (lua_gettop(L) != 1)
-    return luaL_error(L, "expecting exactly 1 argument");
-  luaL_checktype(L, 1, LUA_TSTRING);
-
-  const char* contents = lua_tostring(L, 1);
-  char* cref = NULL;
-  oms_status_enu_t status = oms_importString(contents, &cref);
-
-  lua_pushstring(L, cref ? cref : "");
-  lua_pushinteger(L, status);
-
-  return 2;
-}
-
 //oms_status_enu_t oms_addSystem(const char* cref, oms_system_enu_t type);
 static int OMSimulatorLua_oms_addSystem(lua_State *L)
 {
@@ -446,6 +495,24 @@ static int OMSimulatorLua_oms_getVariableStepSize(lua_State *L)
   return 4;
 }
 
+//OMSAPI oms_status_enu_t OMSCALL oms_faultInjection(const char* signal, oms_fault_type_enu_t faultType, double faultValue);
+static int OMSimulatorLua_oms_faultInjection(lua_State *L)
+{
+  if (lua_gettop(L) != 3)
+    return luaL_error(L, "expecting exactly 3 arguments");
+  luaL_checktype(L, 1, LUA_TSTRING);
+  luaL_checktype(L, 2, LUA_TNUMBER);
+  luaL_checktype(L, 3, LUA_TNUMBER);
+
+  const char* signal = lua_tostring(L, 1);
+  oms_fault_type_enu_t faultType = (oms_fault_type_enu_t)lua_tointeger(L, 2);
+  double faultValue = lua_tonumber(L, 3);
+
+  oms_status_enu_t status = oms_faultInjection(signal, faultType, faultValue);
+  lua_pushinteger(L, status);
+  return 1;
+}
+
 //oms_status_enu_t oms_getBoolean(const char* cref, bool* value);
 static int OMSimulatorLua_oms_getBoolean(lua_State *L)
 {
@@ -558,7 +625,7 @@ static int OMSimulatorLua_oms_setInteger(lua_State *L)
   return 1;
 }
 
-//oms_status_enu_t oms_setReal(const char* cref, double* value);
+// oms_status_enu_t oms_setReal(const char* cref, double value);
 static int OMSimulatorLua_oms_setReal(lua_State *L)
 {
   if (lua_gettop(L) != 2)
@@ -574,6 +641,22 @@ static int OMSimulatorLua_oms_setReal(lua_State *L)
   return 1;
 }
 
+// OMSAPI oms_status_enu_t OMSCALL oms_setRealInputDerivative(const char* cref, double value);
+static int OMSimulatorLua_oms_setRealInputDerivative(lua_State *L)
+{
+  if (lua_gettop(L) != 2)
+    return luaL_error(L, "expecting exactly 2 arguments");
+  luaL_checktype(L, 1, LUA_TSTRING);
+  luaL_checktype(L, 2, LUA_TNUMBER);
+
+  const char* cref = lua_tostring(L, 1);
+  double value = lua_tonumber(L, 2);
+
+  oms_status_enu_t status = oms_setRealInputDerivative(cref, value);
+  lua_pushinteger(L, status);
+  return 1;
+}
+
 //oms_status_enu_t oms_addConnector(const char *cref, oms_causality_enu_t causality, oms_signal_type_enu_t type);
 static int OMSimulatorLua_oms_addConnector(lua_State *L)
 {
@@ -762,6 +845,74 @@ static int OMSimulatorLua_oms_addTLMConnection(lua_State *L)
   return 1;
 }
 
+//oms_status_enu_t oms_addDynamicValueIndicator(const char* signal, const char* lower, const char* upper, double stepSize);
+static int OMSimulatorLua_oms_addDynamicValueIndicator(lua_State *L)
+{
+  if (lua_gettop(L) != 4)
+    return luaL_error(L, "expecting exactly 4 arguments");
+  luaL_checktype(L, 1, LUA_TSTRING);
+  luaL_checktype(L, 2, LUA_TSTRING);
+  luaL_checktype(L, 3, LUA_TSTRING);
+  luaL_checktype(L, 4, LUA_TNUMBER);
+
+  const char* cref = lua_tostring(L, 1);
+  const char* lower = lua_tostring(L, 2);
+  const char* upper = lua_tostring(L, 3);
+  double stepSize = lua_tonumber(L, 4);
+  oms_status_enu_t status = oms_addDynamicValueIndicator(cref, lower, upper, stepSize);
+
+  lua_pushinteger(L, status);
+  return 1;
+}
+
+//oms_status_enu_t oms_addEventIndicator(const char* signal);
+static int OMSimulatorLua_oms_addEventIndicator(lua_State *L)
+{
+  if (lua_gettop(L) != 1)
+    return luaL_error(L, "expecting exactly 1 argument");
+  luaL_checktype(L, 1, LUA_TSTRING);
+
+  const char* cref = lua_tostring(L, 1);
+  oms_status_enu_t status = oms_addEventIndicator(cref);
+
+  lua_pushinteger(L, status);
+  return 1;
+}
+
+//oms_status_enu_t oms_addTimeIndicator(const char* signal);
+static int OMSimulatorLua_oms_addTimeIndicator(lua_State *L)
+{
+  if (lua_gettop(L) != 1)
+    return luaL_error(L, "expecting exactly 1 argument");
+  luaL_checktype(L, 1, LUA_TSTRING);
+
+  const char *ident = lua_tostring(L, 1);
+  oms_status_enu_t status = oms_addTimeIndicator(ident);
+
+  lua_pushinteger(L, status);
+  return 1;
+}
+
+//oms_status_enu_t oms_addStaticValueIndicator(const char* signal, double lower, double upper, double stepSize);
+static int OMSimulatorLua_oms_addStaticValueIndicator(lua_State *L)
+{
+  if (lua_gettop(L) != 4)
+    return luaL_error(L, "expecting exactly 4 arguments");
+  luaL_checktype(L, 1, LUA_TSTRING);
+  luaL_checktype(L, 2, LUA_TNUMBER);
+  luaL_checktype(L, 3, LUA_TNUMBER);
+  luaL_checktype(L, 4, LUA_TNUMBER);
+
+  const char *signal = lua_tostring(L, 1);
+  double lower = lua_tonumber(L, 2);
+  double upper = lua_tonumber(L, 3);
+  double stepSize = lua_tonumber(L, 4);
+  oms_status_enu_t status = oms_addStaticValueIndicator(signal,lower,upper,stepSize);
+
+  lua_pushinteger(L, status);
+  return 1;
+}
+
 //oms_status_enu_t oms_addExternalModel(const char *cref, const char *path, const char *startscript)
 static int OMSimulatorLua_oms_addExternalModel(lua_State *L)
 {
@@ -793,6 +944,11 @@ static int OMSimulatorLua_oms_addSubModel(lua_State *L)
   const char* fmuPath = lua_tostring(L, 2);
   oms_status_enu_t status = oms_addSubModel(cref, fmuPath);
 
+  if (status!=oms_status_ok)
+  {
+    return luaL_error(L, "oms_addSubModel(%s,%s) failed", cref, fmuPath);
+  }
+
   lua_pushinteger(L, status);
 
   return 1;
@@ -1103,261 +1259,6 @@ static int OMSimulatorLua_oms_setFixedStepSize(lua_State *L)
   return 1;
 }
 
-/* **************************************************** */
-/* OMSysIdent API                                       */
-/* **************************************************** */
-
-#ifdef WITH_OMSYSIDENT
-//void* omsi_newSysIdentModel(const char* ident);
-static int OMSimulatorLua_omsi_newSysIdentModel(lua_State *L)
-{
-  if (lua_gettop(L) != 1)
-    return luaL_error(L, "expecting exactly 1 argument");
-  luaL_checktype(L, 1, LUA_TSTRING);
-
-  const char* ident = lua_tostring(L, 1);
-
-  void *pModel = omsi_newSysIdentModel(ident);
-  push_pointer(L, pModel);
-  return 1;
-}
-
-//void omsi_freeSysIdentModel(void* simodel);
-static int OMSimulatorLua_omsi_freeSysIdentModel(lua_State *L)
-{
-  if (lua_gettop(L) != 1)
-    return luaL_error(L, "expecting exactly 1 argument");
-  luaL_checktype(L, 1, LUA_TUSERDATA);
-
-  void *model = topointer(L, 1);
-  omsi_freeSysIdentModel(model);
-  return 0;
-}
-
-//void oms_setReal(void* model, const char* var, double value);
-// oms_status_enu_t omsi_initialize(void* simodel, size_t nSeries, const double* time, size_t nTime, char const* const* inputvars, size_t nInputvars, char const* const* measurementvars, size_t nMeasurementvars);
-static int OMSimulatorLua_omsi_initialize(lua_State *L)
-{
-  if (lua_gettop(L) != 5)
-    return luaL_error(L, "expecting exactly 5 arguments");
-  luaL_checktype(L, 1, LUA_TUSERDATA); // simodel
-  luaL_checktype(L, 2, LUA_TNUMBER);   // nSeries
-  luaL_checktype(L, 3, LUA_TTABLE);    // time
-  luaL_checktype(L, 4, LUA_TTABLE);    // inputvars
-  luaL_checktype(L, 5, LUA_TTABLE);    // measurementvars
-  // luaL_checktype(L, 2, LUA_TSTRING);
-
-  void *model = topointer(L, 1);
-  size_t nSeries = lua_tonumber(L, 2);
-
-  // get size of tables
-  size_t nTime = luaL_len(L, 3);
-  size_t nInputvars = luaL_len(L, 4);
-  size_t nMeasurementvars = luaL_len(L, 5);
-  // create buffers
-  double* time = (double*) malloc(nTime*sizeof(double));
-  char const* * inputvars = (char const**) malloc(nInputvars*sizeof(char const *));
-  char const* * measurementvars = (char const**) malloc(nMeasurementvars*sizeof(char const *));
-
-  //printf("nTime: %d, nInputvars: %d, nMeasurementvars %d\n", (int)nTime, (int)nInputvars, (int)nMeasurementvars);
-
-  int i;
-  for (i=0; i < nTime; ++i) {
-    lua_rawgeti(L, 3, i+1); // push value on stack
-    time[i] = lua_tonumber(L, -1);
-    lua_pop(L, 1); // pop value from stack
-  }
-
-  for (i=0; i < nInputvars; ++i) {
-    lua_rawgeti(L, 4, i+1);
-    inputvars[i] = lua_tostring(L, -1);
-    lua_pop(L, 1);
-  }
-
-  for (i=0; i < nMeasurementvars; ++i) {
-    lua_rawgeti(L, 5, i+1);
-    measurementvars[i] = lua_tostring(L, -1);
-    lua_pop(L, 1);
-  }
-
-  oms_status_enu_t returnValue =
-    omsi_initialize(model, nSeries, time, nTime, inputvars, nInputvars, measurementvars, nMeasurementvars);
-  lua_pushinteger(L, returnValue);
-
-  free(time); free(inputvars); free(measurementvars);
-  return 1;
-}
-
-//oms_status_enu_t omsi_describe(void* simodel);
-static int OMSimulatorLua_omsi_describe(lua_State *L)
-{
-  if (lua_gettop(L) != 1)
-    return luaL_error(L, "expecting exactly 1 argument");
-  luaL_checktype(L, 1, LUA_TUSERDATA);
-
-  void *model = topointer(L, 1);
-  oms_status_enu_t returnValue = omsi_describe(model);
-  lua_pushinteger(L, returnValue);
-  return 1;
-}
-
-// oms_status_enu_t omsi_addMeasurement(void* simodel, size_t iSeries, const char* var, const double* values, size_t nValues);
-static int OMSimulatorLua_omsi_addMeasurement(lua_State *L)
-{
-  if (lua_gettop(L) != 4)
-    return luaL_error(L, "expecting exactly 4 arguments");
-  luaL_checktype(L, 1, LUA_TUSERDATA); // simodel
-  luaL_checktype(L, 2, LUA_TNUMBER);   // iSeries
-  luaL_checktype(L, 3, LUA_TSTRING);   // var
-  luaL_checktype(L, 4, LUA_TTABLE);    // values
-
-  void *model = topointer(L, 1);
-  size_t iSeries = lua_tonumber(L, 2);
-  const char* var = lua_tostring(L, 3);
-  size_t nValues = luaL_len(L, 4);
-
-  double* values = (double*) malloc(nValues*sizeof(double));
-  int i;
-  for (i=0; i < nValues; ++i) {
-    lua_rawgeti(L, 4, i+1); // push value on stack
-    values[i] = lua_tonumber(L, -1);
-    lua_pop(L, 1); // pop value from stack
-  }
-
-  oms_status_enu_t returnValue =
-    omsi_addMeasurement(model, iSeries, var, values, nValues);
-  lua_pushinteger(L, returnValue);
-
-  free(values);
-  return 1;
-}
-
-// oms_status_enu_t omsi_addInput(void* simodel, const char* var, const double* values, size_t nValues);
-static int OMSimulatorLua_omsi_addInput(lua_State *L)
-{
-  if (lua_gettop(L) != 3)
-    return luaL_error(L, "expecting exactly 3 arguments");
-  luaL_checktype(L, 1, LUA_TUSERDATA); // simodel
-  luaL_checktype(L, 2, LUA_TSTRING);   // var
-  luaL_checktype(L, 3, LUA_TTABLE);    // values
-
-  void *model = topointer(L, 1);
-  const char* var = lua_tostring(L, 2);
-  size_t nValues = luaL_len(L, 3);
-
-  double* values = (double*) malloc(nValues*sizeof(double));
-  int i;
-  for (i=0; i < nValues; ++i) {
-    lua_rawgeti(L, 3, i+1); // push value on stack
-    values[i] = lua_tonumber(L, -1);
-    lua_pop(L, 1); // pop value from stack
-  }
-
-  oms_status_enu_t returnValue =
-    omsi_addInput(model, var, values, nValues);
-  lua_pushinteger(L, returnValue);
-
-  free(values);
-  return 1;
-}
-
-// oms_status_enu_t omsi_addParameter(void* simodel, const char* var, double startvalue);
-static int OMSimulatorLua_omsi_addParameter(lua_State *L)
-{
-  if (lua_gettop(L) != 3)
-    return luaL_error(L, "expecting exactly 3 arguments");
-  luaL_checktype(L, 1, LUA_TUSERDATA); // simodel
-  luaL_checktype(L, 2, LUA_TSTRING);   // var
-  luaL_checktype(L, 3, LUA_TNUMBER);   // startvalue
-
-  void *model = topointer(L, 1);
-  const char* var = lua_tostring(L, 2);
-  double startvalue = lua_tonumber(L, 3);
-
-  oms_status_enu_t returnValue =
-    omsi_addParameter(model, var, startvalue);
-  lua_pushinteger(L, returnValue);
-  return 1;
-}
-
-// oms_status_enu_t omsi_getParameter(void* simodel, const char* var, double* startvalue, double* estimatedvalue);
-static int OMSimulatorLua_omsi_getParameter(lua_State *L)
-{
-  if (lua_gettop(L) != 2)
-    return luaL_error(L, "expecting exactly 2 arguments");
-  luaL_checktype(L, 1, LUA_TUSERDATA); // simodel
-  luaL_checktype(L, 2, LUA_TSTRING);   // var
-
-  void *model = topointer(L, 1);
-  const char* var = lua_tostring(L, 2);
-
-  double startvalue, estimatedvalue;
-  oms_status_enu_t returnValue =
-    omsi_getParameter(model, var, &startvalue, &estimatedvalue);
-  lua_pushinteger(L, returnValue);
-  lua_pushnumber(L, startvalue);
-  lua_pushnumber(L, estimatedvalue);
-  return 3;
-}
-
-// oms_status_enu_t omsi_solve(void* simodel, const char* reporttype);
-static int OMSimulatorLua_omsi_solve(lua_State *L)
-{
-  if (lua_gettop(L) != 2)
-    return luaL_error(L, "expecting exactly 2 arguments");
-  luaL_checktype(L, 1, LUA_TUSERDATA); // simodel
-  luaL_checktype(L, 2, LUA_TSTRING);   // reporttype
-
-  void *model = topointer(L, 1);
-  const char* reporttype = lua_tostring(L, 2);
-
-  oms_status_enu_t returnValue =
-    omsi_solve(model, reporttype);
-  lua_pushinteger(L, returnValue);
-  return 1;
-}
-
-// oms_status_enu_t omsi_setOptions_max_num_iterations(void* simodel, size_t max_num_iterations);
-static int OMSimulatorLua_omsi_setOptions_max_num_iterations(lua_State *L)
-{
-  if (lua_gettop(L) != 2)
-    return luaL_error(L, "expecting exactly 2 arguments");
-  luaL_checktype(L, 1, LUA_TUSERDATA); // simodel
-  luaL_checktype(L, 2, LUA_TNUMBER);   // max_num_iterations
-
-  void *model = topointer(L, 1);
-  int max_num_iterations = lua_tointeger(L, 2);
-
-  oms_status_enu_t returnValue =
-    omsi_setOptions_max_num_iterations(model, max_num_iterations);
-  lua_pushinteger(L, returnValue);
-  return 1;
-}
-
-// oms_status_enu_t omsi_getState(void* simodel, omsi_simodelstate_t* state);
-static int OMSimulatorLua_omsi_getState(lua_State *L)
-{
-  if (lua_gettop(L) != 1)
-    return luaL_error(L, "expecting exactly 1 argument");
-  luaL_checktype(L, 1, LUA_TUSERDATA); // simodel
-
-  void *model = topointer(L, 1);
-
-  omsi_simodelstate_t state;
-  oms_status_enu_t returnValue =
-    omsi_getState(model, &state);
-  lua_pushinteger(L, returnValue);
-  switch (state) {
-    case omsi_simodelstate_constructed: lua_pushstring(L, "constructed"); break;
-    case omsi_simodelstate_initialized: lua_pushstring(L, "initialized"); break;
-    case omsi_simodelstate_convergence: lua_pushstring(L, "convergence"); break;
-    case omsi_simodelstate_no_convergence: lua_pushstring(L, "no_convergence"); break;
-    case omsi_simodelstate_failure: lua_pushstring(L, "failure"); break;
-  }
-  return 2;
-}
-#endif /* WITH_OMSYSIDENT */
-
 DLLEXPORT int luaopen_OMSimulatorLua(lua_State *L)
 {
   REGISTER_LUA_CALL(oms_addBus);
@@ -1365,10 +1266,14 @@ DLLEXPORT int luaopen_OMSimulatorLua(lua_State *L)
   REGISTER_LUA_CALL(oms_addConnector);
   REGISTER_LUA_CALL(oms_addConnectorToBus);
   REGISTER_LUA_CALL(oms_addConnectorToTLMBus);
+  REGISTER_LUA_CALL(oms_addDynamicValueIndicator);
+  REGISTER_LUA_CALL(oms_addEventIndicator);
   REGISTER_LUA_CALL(oms_addExternalModel);
   REGISTER_LUA_CALL(oms_addSignalsToResults);
+  REGISTER_LUA_CALL(oms_addStaticValueIndicator);
   REGISTER_LUA_CALL(oms_addSubModel);
   REGISTER_LUA_CALL(oms_addSystem);
+  REGISTER_LUA_CALL(oms_addTimeIndicator);
   REGISTER_LUA_CALL(oms_addTLMBus);
   REGISTER_LUA_CALL(oms_addTLMConnection);
   REGISTER_LUA_CALL(oms_compareSimulationResults);
@@ -1379,9 +1284,13 @@ DLLEXPORT int luaopen_OMSimulatorLua(lua_State *L)
   REGISTER_LUA_CALL(oms_deleteConnectorFromTLMBus);
   REGISTER_LUA_CALL(oms_export);
   REGISTER_LUA_CALL(oms_exportDependencyGraphs);
+  REGISTER_LUA_CALL(oms_exportSnapshot);
+  REGISTER_LUA_CALL(oms_exportSSVTemplate);
+  REGISTER_LUA_CALL(oms_faultInjection);
   REGISTER_LUA_CALL(oms_getBoolean);
   REGISTER_LUA_CALL(oms_getFixedStepSize);
   REGISTER_LUA_CALL(oms_getInteger);
+  REGISTER_LUA_CALL(oms_getModelState);
   REGISTER_LUA_CALL(oms_getReal);
   REGISTER_LUA_CALL(oms_getSolver);
   REGISTER_LUA_CALL(oms_getStartTime);
@@ -1390,11 +1299,12 @@ DLLEXPORT int luaopen_OMSimulatorLua(lua_State *L)
   REGISTER_LUA_CALL(oms_getVariableStepSize);
   REGISTER_LUA_CALL(oms_getVersion);
   REGISTER_LUA_CALL(oms_importFile);
-  REGISTER_LUA_CALL(oms_importString);
+  REGISTER_LUA_CALL(oms_importSnapshot);
   REGISTER_LUA_CALL(oms_initialize);
   REGISTER_LUA_CALL(oms_instantiate);
   REGISTER_LUA_CALL(oms_list);
   REGISTER_LUA_CALL(oms_listUnconnectedConnectors);
+  REGISTER_LUA_CALL(oms_loadSnapshot);
   REGISTER_LUA_CALL(oms_newModel);
   REGISTER_LUA_CALL(oms_parseModelName);
   REGISTER_LUA_CALL(oms_removeSignalsFromResults);
@@ -1409,6 +1319,7 @@ DLLEXPORT int luaopen_OMSimulatorLua(lua_State *L)
   REGISTER_LUA_CALL(oms_setLoggingLevel);
   REGISTER_LUA_CALL(oms_setMaxLogFileSize);
   REGISTER_LUA_CALL(oms_setReal);
+  REGISTER_LUA_CALL(oms_setRealInputDerivative);
   REGISTER_LUA_CALL(oms_setResultFile);
   REGISTER_LUA_CALL(oms_setSignalFilter);
   REGISTER_LUA_CALL(oms_setSolver);
@@ -1424,43 +1335,25 @@ DLLEXPORT int luaopen_OMSimulatorLua(lua_State *L)
   REGISTER_LUA_CALL(oms_stepUntil);
   REGISTER_LUA_CALL(oms_terminate);
 
-  /* ************************************ */
-  /* OMSysIdent API                       */
-  /* ************************************ */
-#ifdef WITH_OMSYSIDENT
-  REGISTER_LUA_CALL(omsi_addMeasurement);
-  REGISTER_LUA_CALL(omsi_addInput);
-  REGISTER_LUA_CALL(omsi_addParameter);
-  REGISTER_LUA_CALL(omsi_describe);
-  REGISTER_LUA_CALL(omsi_freeSysIdentModel);
-  REGISTER_LUA_CALL(omsi_getParameter);
-  REGISTER_LUA_CALL(omsi_getState);
-  REGISTER_LUA_CALL(omsi_initialize);
-  REGISTER_LUA_CALL(omsi_newSysIdentModel);
-  REGISTER_LUA_CALL(omsi_setOptions_max_num_iterations);
-  REGISTER_LUA_CALL(omsi_solve);
-#endif /* WITH_OMSYSIDENT */
+  // oms_tlm_interpolation_t
+  REGISTER_LUA_ENUM(oms_tlm_no_interpolation);
+  REGISTER_LUA_ENUM(oms_tlm_coarse_grained);
+  REGISTER_LUA_ENUM(oms_tlm_fine_grained);
 
-  // Add enumerable constants
-  lua_pushnumber(L, 0);
-  lua_setglobal(L, "input");
-  lua_pushnumber(L, 1);
-  lua_setglobal(L, "output");
-  lua_pushnumber(L, 3);
-  lua_setglobal(L, "bidirectional");
-
-  lua_pushnumber(L, 0);
-  lua_setglobal(L, "default");
-  lua_pushnumber(L, 1);
-  lua_setglobal(L, "coarsegrained");
-  lua_pushnumber(L, 2);
-  lua_setglobal(L, "finegrained");
+  // oms_causality_enu_t;
+  REGISTER_LUA_ENUM(oms_causality_input);
+  REGISTER_LUA_ENUM(oms_causality_output);
+  REGISTER_LUA_ENUM(oms_causality_parameter);
+  REGISTER_LUA_ENUM(oms_causality_bidir);
+  REGISTER_LUA_ENUM(oms_causality_undefined);
 
   // oms_solver_enu_t
   REGISTER_LUA_ENUM(oms_solver_sc_explicit_euler);
   REGISTER_LUA_ENUM(oms_solver_sc_cvode);
   REGISTER_LUA_ENUM(oms_solver_wc_ma);
   REGISTER_LUA_ENUM(oms_solver_wc_mav);
+  REGISTER_LUA_ENUM(oms_solver_wc_assc);
+  REGISTER_LUA_ENUM(oms_solver_wc_mav2);
 
   // oms_system_enu_t
   REGISTER_LUA_ENUM(oms_system_none);
@@ -1476,6 +1369,14 @@ DLLEXPORT int luaopen_OMSimulatorLua(lua_State *L)
   REGISTER_LUA_ENUM(oms_status_fatal);
   REGISTER_LUA_ENUM(oms_status_pending);
 
+  // oms_modelState_enu_t
+  REGISTER_LUA_ENUM(oms_modelState_virgin);
+  REGISTER_LUA_ENUM(oms_modelState_enterInstantiation);
+  REGISTER_LUA_ENUM(oms_modelState_instantiated);
+  REGISTER_LUA_ENUM(oms_modelState_initialization);
+  REGISTER_LUA_ENUM(oms_modelState_simulation);
+  REGISTER_LUA_ENUM(oms_modelState_error);
+
   // oms_signal_type_enu_t
   REGISTER_LUA_ENUM(oms_signal_type_real);
   REGISTER_LUA_ENUM(oms_signal_type_integer);
@@ -1490,5 +1391,10 @@ DLLEXPORT int luaopen_OMSimulatorLua(lua_State *L)
   REGISTER_LUA_ENUM(oms_tlm_domain_hydraulic);
   REGISTER_LUA_ENUM(oms_tlm_domain_electric);
 
+  // oms_fault_type_enu_t
+  REGISTER_LUA_ENUM(oms_fault_type_bias);
+  REGISTER_LUA_ENUM(oms_fault_type_gain);
+  REGISTER_LUA_ENUM(oms_fault_type_const);
+
   return 0;
 }
